@@ -1390,11 +1390,12 @@ def laplace(ex, t, s, algorithm='maxima'):
 
       - ``'giac'`` - use Giac
     
-    NOTES:
+    .. NOTE::
     
-    - The ``'sympy'`` algorithm returns the tuple (`F`, `a`, ``cond``) where `F` is the Laplace 
-      transform of `f(t)`, `Re(s)>a` is the half-plane of convergence, and cond 
-      are auxiliary convergence conditions.
+        The ``'sympy'`` algorithm returns the tuple (`F`, `a`, ``cond``)
+        where `F` is the Laplace transform of `f(t)`,
+        `Re(s)>a` is the half-plane of convergence, and ``cond`` are
+        auxiliary convergence conditions.
 
     .. SEEALSO::
 
