@@ -215,7 +215,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
                 sage: F = CombinatorialFreeModule(QQ, ['a','b','c'])
                 sage: F.basis()
-                Finite family {'a': B['a'], 'c': B['c'], 'b': B['b']}
+                Finite family {'a': B['a'], 'b': B['b'], 'c': B['c']}
 
             ::
 
@@ -771,7 +771,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: S3A = S3.algebra(QQ)
                 sage: basis = S3A.annihilator_basis(S3A.algebra_generators(), S3A.bracket)
                 sage: basis
-                ((), (2,3) + (1,2) + (1,3), (1,2,3) + (1,3,2))
+                ((), (1,2,3) + (1,3,2), (2,3) + (1,2) + (1,3))
                 sage: center = S3A.submodule(basis,
                 ....:                        category=AlgebrasWithBasis(QQ).Subobjects(),
                 ....:                        already_echelonized=True)
@@ -782,7 +782,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: center.print_options(prefix='c')
                 sage: c = center.basis()
                 sage: c[1].lift()
-                (2,3) + (1,2) + (1,3)
+                (1,2,3) + (1,3,2)
                 sage: c[0]^2
                 c[0]
                 sage: e = 1/6*(c[0]+c[1]+c[2])
@@ -2155,7 +2155,7 @@ class ModulesWithBasis(CategoryWithAxiom_over_base_ring):
                     sage: A.an_element()
                     B[word: ] + 2*B[word: a] + 3*B[word: b] + B[word: bab]
                     sage: B.an_element()
-                    B[()] + B[(1,2)] + 3*B[(1,2,3)] + 2*B[(1,3)]
+                    B[()] + B[(1,2)] + 3*B[(1,2,3)] + 2*B[(1,3,2)]
                     sage: cartesian_product((A, B, A)).an_element()           # indirect doctest
                     2*B[(0, word: )] + 2*B[(0, word: a)] + 3*B[(0, word: b)]
                 """
