@@ -47,7 +47,7 @@ from .letters import CrystalOfLetters
 from .spins import CrystalOfSpins, CrystalOfSpinsMinus, CrystalOfSpinsPlus
 from sage.combinat.crystals.tensor_product_element import (TensorProductOfCrystalsElement,
         TensorProductOfRegularCrystalsElement, CrystalOfTableauxElement,
-        TensorProductOfSuperCrystalsElement)
+        TensorProductOfSuperCrystalsElement, TensorProductOfQueerSuperCrystalsElement)
 from sage.misc.flatten import flatten
 from sage.structure.element import get_coercion_model
 
@@ -645,6 +645,47 @@ class FullTensorProductOfSuperCrystals(FullTensorProductOfCrystals):
     class Element(TensorProductOfSuperCrystalsElement):
         pass
 
+class FullTensorProductOfQueerSuperCrystals(FullTensorProductOfCrystals):
+    r"""
+    Tensor product of queer super crystals.
+    """
+    @cached_method
+    def index_set(self):
+        """
+        Return the enlarged index set.
+
+        EXAMPLES::
+
+            sage: Q = crystals.Letters(['Q',3])
+            sage: T = tensor([Q,Q])
+            sage: T.index_set()
+            (-4, -3, -2, -1, 1, 2)
+        """
+        n = self.cartan_type().n
+        return tuple(range(-2*n,0)) + tuple(range(1,n+1))
+
+    @cached_method
+    def _long_element(self):
+        r"""
+        Return the long element in `S_n`.
+
+        This method is used in the construction of the crystal operators
+        `e_i` and `f_i`.
+
+        EXAMPLES::
+
+            sage: Q = crystals.Letters(['Q', 4])
+            sage: T = tensor([Q,Q,Q,Q])
+            sage: T._long_element()
+            (3, 2, 1, 3, 2, 3)
+        """
+        from sage.combinat.permutation import Permutations
+        n = self.cartan_type().n
+        return tuple(Permutations(n+1).long_element().reduced_word())
+
+    class Element(TensorProductOfQueerSuperCrystalsElement):
+        pass
+
 #########################################################
 ## Crystal of tableaux
 
