@@ -95,6 +95,8 @@ Subsets and set partitions
 - :ref:`sage.combinat.set_partition_ordered`
 - :ref:`sage.combinat.set_partition`
 - :ref:`sage.combinat.diagram_algebras`
+- :class:`~sage.combinat.multiset_partition_into_sets_ordered.OrderedMultisetPartitionsIntoSets`,
+  :class:`~sage.combinat.multiset_partition_into_sets_ordered.OrderedMultisetPartitionIntoSets`
 
 Trees
 -----
@@ -132,7 +134,6 @@ Backtracking solvers and generic enumerated sets
 Low level enumerated sets
 -------------------------
 
-- :ref:`sage.combinat.multichoose_nk`
 - :ref:`sage.combinat.gray_codes`
 
 Misc enumerated sets
