@@ -50,7 +50,7 @@ from sage.combinat.words.words import Words
 
 @add_metaclass(InheritComparisonClasscallMetaclass)
 class SkewTableau(ClonableList):
-    """
+    r"""
     A skew tableau.
 
     Note that Sage by default uses the English convention for partitions and
@@ -77,7 +77,6 @@ class SkewTableau(ClonableList):
 
         sage: SkewTableau(chain=[[2], [2, 1], [3, 1], [4, 3, 2, 1]])
         [[None, None, 2, 3], [1, 3, 3], [3, 3], [3]]
-
     """
     @staticmethod
     def __classcall_private__(cls, st=None, expr=None, chain=None):
@@ -122,7 +121,7 @@ class SkewTableau(ClonableList):
             TypeError: 'tuple' object does not support item assignment
         """
         try:
-            st = map(tuple, st)
+            st = [tuple(t) for t in st]
         except TypeError:
             raise TypeError("each element of the skew tableau must be an iterable")
 
@@ -503,7 +502,7 @@ class SkewTableau(ClonableList):
         return Permutation(word)
 
     def weight(self):
-        """
+        r"""
         Return the weight (aka evaluation) of the tableau ``self``.
         Trailing zeroes are omitted when returning the weight.
 
@@ -549,15 +548,15 @@ class SkewTableau(ClonableList):
             sage: all(by_word(t) == SkewTableau(t).weight() for t in SST)
             True
         """
-        if len(self) == 0:
+        if len(self) == 0 or all(c is None for row in self for c in row):
             return []
-        m = max(max(row) for row in self)
+        m = max(c for row in self for c in row if c is not None)
         if m is None:
             return []
         res = [0] * m
         for row in self:
             for i in row:
-                if not (i is None) and i > 0:
+                if (i is not None) and i > 0:
                     res[i - 1] += 1
         return res
 
@@ -736,7 +735,7 @@ class SkewTableau(ClonableList):
         return SkewPartition([self.restriction_outer_shape(n), self.inner_shape()])
 
     def to_chain(self, max_entry=None):
-        """
+        r"""
         Return the chain of partitions corresponding to the (semi)standard
         skew tableau ``self``.
 
@@ -778,12 +777,10 @@ class SkewTableau(ClonableList):
             [[1]]
         """
         if max_entry is None:
-            if len(self) == 0:
+            if len(self) == 0 or all(c is None for row in self for c in row):
                 max_entry = 0
             else:
-                max_entry = max(max(row) for row in self)
-            if max_entry is None:
-                max_entry = 0
+                max_entry = max(c for row in self for c in row if c is not None)
         return [self.restriction_outer_shape(x) for x in range(max_entry+1)]
 
     def slide(self, corner=None, return_vacated=False):
@@ -2535,7 +2532,7 @@ class SkewTableau_class(SkewTableau):
         self.__init__(SkewTableaux(), state['_list'])
 
 # October 2012: fixing outdated pickles which use the classes being deprecated
-from sage.structure.sage_object import register_unpickle_override
+from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.combinat.skew_tableau', 'StandardSkewTableaux_n',  StandardSkewTableaux_size)
 register_unpickle_override('sage.combinat.skew_tableau', 'SemistandardSkewTableaux_n',  SemistandardSkewTableaux_size)
 register_unpickle_override('sage.combinat.skew_tableau', 'SemistandardSkewTableaux_nmu',  SemistandardSkewTableaux_size_weight)
