@@ -630,7 +630,7 @@ class WordDatatype_iter(WordDatatype):
             self._data = iter
         else:
             self._len = length
-            self._data = itertools.islice(iter, length)
+            self._data = itertools.islice(iter, int(length))
 
         self._parent = parent
         self._hash = None
@@ -832,20 +832,22 @@ class WordDatatype_iter(WordDatatype):
                 if not(key.start is None) and key.start < 0 or \
                         not(key.stop is None) and key.stop < 0:
                     raise ValueError("for infinite words, start and stop values cannot be negative")
-                step = 1 if key.step is None else key.step
+                step = 1 if key.step is None else int(key.step)
                 if step >= 0:
-                    start = 0 if key.start is None else key.start
+                    start = 0 if key.start is None else int(key.start)
                     if key.stop is None:
                         length = Infinity
+                        stop = None
                     else: # key.stop > 0
                         length = int(max(0,ceil((key.stop-start)/float(step))))
+                        stop = int(key.stop)
                     data = itertools.islice(self, start, key.stop, step)
                 else:
                     if key.start is None or key.start < 0:
                         raise ValueError("start value must be nonnegative for negative step values")
-                    start = key.start
-                    stop = 0 if key.stop is None else key.stop
-                    length = int(max(0,ceil((key.stop-start)/float(step))))
+                    start = int(key.start)
+                    stop = 0 if key.stop is None else int(key.stop)
+                    length = int(max(0,ceil((stop-start)/float(step))))
                     data = list(itertools.islice(self, start+1))[key]
 
                 if length is None or length is Infinity:
