@@ -105,6 +105,20 @@ class SBox(SageObject):
             sage: S(0)
             7
 
+        Construct S-box from univariate polynomial.::
+
+            sage: R = PolynomialRing(GF(2**3), 'x')
+            sage: inv = R.gen()**(2**3-2)
+            sage: inv = SBox(inv); inv
+            (0, 1, 5, 6, 7, 2, 3, 4)
+            sage: inv.differential_uniformity()
+            2
+
+            sage: SBox(PolynomialRing(GF(3**3), 'x').gen())
+            Traceback (most recent call last):
+            ...
+            TypeError: Only polynomials over rings with characteristic 2 allowed
+
         TESTS::
 
             sage: from sage.crypto.sbox import SBox
@@ -115,14 +129,25 @@ class SBox(SageObject):
             sage: S = SBox(1, 2, 3)
             Traceback (most recent call last):
             ...
-            TypeError: Lookup table length is not a power of 2.
+            TypeError: Lookup table length is not a power of 2
             sage: S = SBox(5, 6, 0, 3, 4, 2, 1, 2)
             sage: S.n
             3
         """
+        from sage.rings.polynomial.polynomial_element import is_Polynomial
+
         if "S" in kwargs:
-            S = kwargs["S"]
-        elif len(args) == 1:
+            args = kwargs["S"]
+
+        if len(args) == 1 and is_Polynomial(args[0]):
+            # SBox defined via Univariate Polynomial, compute lookup table
+            # by evaluating the polynomial on every base_ring element
+            poly = args[0]
+            R = poly.parent().base_ring()
+            if R.characteristic() != 2:
+                raise TypeError("Only polynomials over rings with characteristic 2 allowed")
+            S = [poly(v) for v in sorted(R)]
+        elif len(args) == 1 and isinstance(args[0], (list, tuple)):
             S = args[0]
         elif len(args) > 1:
             S = args
@@ -132,18 +157,18 @@ class SBox(SageObject):
         _S = []
         for e in S:
             if is_FiniteFieldElement(e):
-                e = e.polynomial().change_ring(ZZ).subs( e.parent().characteristic() )
+                e = e.polynomial().change_ring(ZZ).subs(e.parent().characteristic())
             _S.append(e)
         S = _S
 
         if not ZZ(len(S)).is_power_of(2):
-            raise TypeError("Lookup table length is not a power of 2.")
+            raise TypeError("Lookup table length is not a power of 2")
         self._S = S
 
         self.m = ZZ(len(S)).exact_log(2)
         self.n = ZZ(max(S)).nbits()
         self._F = GF(2)
-        self._big_endian = kwargs.get("big_endian",True)
+        self._big_endian = kwargs.get("big_endian", True)
 
         self.differential_uniformity = self.maximal_difference_probability_absolute
 
@@ -1321,7 +1346,9 @@ class SBox(SageObject):
             |\{ x \in \mathbb{F}_2^m | S^{-1}( S(x) \oplus \Delta_o) \oplus
                S^{-1}( S(x \oplus \Delta_i) \oplus \Delta_o) = \Delta_i\}|.
 
-        For more results concering boomerang connectivity matrix, see [CHPSS18]_ .
+        For more results concerning boomerang connectivity matrix, see [CHPSS18]_ .
+        The algorithm used here, is the one from Dunkelman, published in a
+        preprint, see [Du2018]_ .
 
         EXAMPLES::
 
@@ -1344,6 +1371,8 @@ class SBox(SageObject):
             [16  0  2  2  0  0  2  2  2  2  0  0  2  2  0  0]
             [16  8  0  0  8  0  0  0  0  0  0  8  0  0  8 16]
         """
+        from itertools import product
+
         Si = self.inverse()
 
         m = self.input_size()
@@ -1352,19 +1381,23 @@ class SBox(SageObject):
         nrows = 1 << m
         ncols = 1 << n
 
-        A = Matrix(ZZ, nrows, ncols)
+        A = []
 
-        for x in range(nrows):
-            for di in range(nrows):
-                for do in range(ncols):
-                    l = Si( self(x) ^ do )
-                    r = Si( self(x ^ di) ^ do )
-                    if (l ^ r == di):
-                        A[di, do] += 1
+        for delta_in in range(ncols):
+            table = [list() for _ in range(ncols)]
+            for x in range(nrows):
+                table[x ^ self(Si(x) ^ delta_in)].append(x)
 
+            row = [0]*ncols
+            for l in table:
+                for i, j in product(l, l):
+                    row[i ^ j] += 1
+            A += row
+
+        A = Matrix(ZZ, nrows, ncols, A)
         A.set_immutable()
-        return A
 
+        return A
 
     def linear_structures(self):
         r"""
