@@ -562,21 +562,12 @@ class Stock:
             1212407640 187.75 188.00 187.75 188.00       2000,
             1212405780 187.80 187.80 187.80 187.80        100
             ]
-
-        This tests a file that doesn't exist::
-
-            sage: finance.Stock("AAPL").load_from_file("I am not a file")
-            Traceback (most recent call last):
-            ...
-            IOError: [Errno 2] No such file or directory: 'I am not a file'
         """
-        file_obj = open(file, 'r')
-        R = file_obj.read();
-        self.__historical = self._load_from_csv(R)
-        file_obj.close()
+        with open(file) as file_obj:
+            R = file_obj.read()
+            self.__historical = self._load_from_csv(R)
         return self.__historical
 
-
     def _load_from_csv(self, R):
         r"""
         EXAMPLES:
