@@ -768,7 +768,7 @@ class Func_chebyshev_T(ChebyshevFunction):
             True
             sage: R.<t> = Zp(2, 8, 'capped-abs')[]
             sage: chebyshev_T(10^6+1, t)
-            (2^7 + O(2^8))*t^5 + (O(2^8))*t^4 + (2^6 + O(2^8))*t^3 + (O(2^8))*t^2 + (1 + 2^6 + O(2^8))*t + (O(2^8))
+            (2^7 + O(2^8))*t^5 + O(2^8)*t^4 + (2^6 + O(2^8))*t^3 + O(2^8)*t^2 + (1 + 2^6 + O(2^8))*t + O(2^8)
         """
         if n == 0:
             return parent(x).one()
@@ -985,7 +985,7 @@ class Func_chebyshev_U(ChebyshevFunction):
             True
             sage: R.<t> = Zp(2, 6, 'capped-abs')[]
             sage: chebyshev_U(10^6+1, t)
-            (2 + O(2^6))*t + (O(2^6))
+            (2 + O(2^6))*t + O(2^6)
         """
         if n == -1:
             return parent(x).zero()
@@ -1352,7 +1352,7 @@ class Func_legendre_Q(BuiltinFunction):
 
         REFERENCE:
 
-        - T. M. Dunster, Legendre and Related Functions, http://dlmf.nist.gov/14.7#E2
+        - T. M. Dunster, Legendre and Related Functions, https://dlmf.nist.gov/14.7#E2
 
         EXAMPLES::
 
@@ -1538,7 +1538,7 @@ class Func_assoc_legendre_P(BuiltinFunction):
 
         REFERENCE:
 
-        - T. M. Dunster, Legendre and Related Functions, http://dlmf.nist.gov/14.7#E10
+        - T. M. Dunster, Legendre and Related Functions, https://dlmf.nist.gov/14.7#E10
         """
         from sage.functions.other import factorial
         if n < 0 or m < 0:
@@ -1920,7 +1920,7 @@ class Func_ultraspherical(GinacFunction):
         sage: t = PolynomialRing(RationalField(),"t").gen()
         sage: gegenbauer(3,2,t)
         32*t^3 - 12*t
-        sage: _=var('x');
+        sage: _ = var('x')
         sage: for N in range(100):
         ....:     n = ZZ.random_element().abs() + 5
         ....:     a = QQ.random_element().abs() + 5
