@@ -187,8 +187,8 @@ def wigner_3j(j_1, j_2, j_3, m_1, m_2, m_3, prec=None):
     if isinstance(ressqrt, ComplexNumber):
         ressqrt = ressqrt.real()
 
-    imin = max(-j_3 + j_1 + m_2, -j_3 + j_2 - m_1, 0)
-    imax = min(j_2 + m_2, j_1 - m_1, j_1 + j_2 - j_3)
+    imin = int(max(-j_3 + j_1 + m_2, -j_3 + j_2 - m_1, 0))
+    imax = int(min(j_2 + m_2, j_1 - m_1, j_1 + j_2 - j_3))
     sumres = 0
     for ii in range(imin, imax + 1):
         den = _Factlist[ii] * \
@@ -360,8 +360,8 @@ def racah(aa, bb, cc, dd, ee, ff, prec=None):
         _big_delta_coeff(bb, dd, ff, prec)
     if prefac == 0:
         return 0
-    imin = max(aa + bb + ee, cc + dd + ee, aa + cc + ff, bb + dd + ff)
-    imax = min(aa + bb + cc + dd, aa + dd + ee + ff, bb + cc + ee + ff)
+    imin = int(max(aa + bb + ee, cc + dd + ee, aa + cc + ff, bb + dd + ff))
+    imax = int(min(aa + bb + cc + dd, aa + dd + ee + ff, bb + cc + ee + ff))
 
     maxfact = max(imax + 1, aa + bb + cc + dd, aa + dd + ee + ff, \
                       bb + cc + ee + ff)
@@ -547,7 +547,7 @@ def wigner_9j(j_1, j_2, j_3, j_4, j_5, j_6, j_7, j_8, j_9, prec=None):
     algebra system [RH2003]_.
     """
     imin = 0
-    imax = min(j_1 + j_9, j_2 + j_6, j_4 + j_8)
+    imax = int(min(j_1 + j_9, j_2 + j_6, j_4 + j_8))
 
     sumres = 0
     for kk in range(imin, imax + 1):
