@@ -10,20 +10,20 @@ EXAMPLES::
     ....:     X = ToricVariety(fan)
     ....:     ideal = X.affine_algebraic_patch(cone).defining_ideal()
     ....:     print("{} {}".format(lp.n_vertices(), ideal.hilbert_series()))
-    3 (-t^2 - 7*t - 1)/(t^3 - 3*t^2 + 3*t - 1)
-    3 (-t^2 - t - 1)/(t^3 - 3*t^2 + 3*t - 1)
+    3 (t^2 + 7*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
+    3 (t^2 + t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     3 (t^2 + 6*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     3 (t^2 + 2*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     3 (t^2 + 4*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
-    4 (-t^2 - 5*t - 1)/(t^3 - 3*t^2 + 3*t - 1)
-    4 (-t^2 - 3*t - 1)/(t^3 - 3*t^2 + 3*t - 1)
+    4 (t^2 + 5*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
+    4 (t^2 + 3*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     4 (t^2 + 2*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     4 (t^2 + 6*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     4 (t^2 + 6*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     4 (t^2 + 2*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     4 (t^2 + 4*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
-    5 (-t^2 - 3*t - 1)/(t^3 - 3*t^2 + 3*t - 1)
-    5 (-t^2 - 5*t - 1)/(t^3 - 3*t^2 + 3*t - 1)
+    5 (t^2 + 3*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
+    5 (t^2 + 5*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     5 (t^2 + 4*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
     6 (t^2 + 4*t + 1)/(-t^3 + 3*t^2 - 3*t + 1)
 """
@@ -363,7 +363,7 @@ class PALPreader(SageObject):
             sage: from sage.geometry.polyhedron.palp_database import PALPreader
             sage: polygons = PALPreader(2)
             sage: polygons.__iter__()
-            <generator object _iterate_Polyhedron at 0x...>
+            <generator object ..._iterate_Polyhedron at 0x...>
         """
         iterator = self._iterate()
         return iterator(None, None, None)
