@@ -51,7 +51,7 @@ A 2-dimensional point configuration::
 .. PLOT::
     :width: 300 px
 
-    p = PointConfiguration([[0,0],[0,1],[1,0],[1,1],[-1,-1]])
+    p = PointConfiguration([[-1,-1],[1,1],[1,0],[0,1],[0,0]])
     sphinx_plot(p.plot(axes=False))
 
 A triangulation of it::
@@ -504,7 +504,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         EXAMPLES::
 
-            sage: p = PointConfiguration([[1,1], [2,2], [3,3]]);
+            sage: p = PointConfiguration([[1,1], [2,2], [3,3]])
             sage: list(p)     # indirect doctest
             [P(1, 1), P(2, 2), P(3, 3)]
             sage: [ p[i] for i in range(0,p.n_points()) ]
@@ -1193,7 +1193,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         EXAMPLES::
 
-            sage: triangle = PointConfiguration([[0,0], [1,-1], [1,0], [1,1]]);
+            sage: triangle = PointConfiguration([[0,0], [1,-1], [1,0], [1,1]])
             sage: triangle.point(2)
             P(1, 0)
             sage: triangle.face_codimension(2)
@@ -1226,7 +1226,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         EXAMPLES::
 
-            sage: triangle = PointConfiguration([[-1,0], [0,0], [1,-1], [1,0], [1,1]]);
+            sage: triangle = PointConfiguration([[-1,0], [0,0], [1,-1], [1,0], [1,1]])
             sage: triangle.face_interior()
             ((1,), (3,), (0, 2, 4))
             sage: triangle.face_interior(dim=0)    # the vertices of the convex hull
@@ -1269,7 +1269,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         EXAMPLES::
 
-            sage: p = PointConfiguration([[-1,0], [0,0], [1,-1], [1,0], [1,1]]);
+            sage: p = PointConfiguration([[-1,0], [0,0], [1,-1], [1,0], [1,1]])
             sage: list(p)
             [P(-1, 0), P(0, 0), P(1, -1), P(1, 0), P(1, 1)]
             sage: q = p.exclude_points([3])
@@ -1828,7 +1828,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
         return p_max
 
 
-    def contained_simplex(self, large=True, initial_point=None):
+    def contained_simplex(self, large=True, initial_point=None, point_order=None):
         """
         Return a simplex contained in the point configuration.
 
@@ -1841,6 +1841,10 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
           :class:`~sage.geometry.triangulation.base.Point` or ``None``
           (default). A specific point to start with when picking the
           simplex vertices.
+          
+        - ``point_order`` -- a list or tuple of (some or all)
+          :class:`~sage.geometry.triangulation.base.Point` s or ``None``
+          (default).
 
         OUTPUT:
 
@@ -1849,6 +1853,12 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
         sucessively picking the farthest point. This will ensure that
         the simplex is not unnecessarily small, but will in general
         not return a maximal simplex.
+        If a ``point_order`` is specified, the simplex is greedily
+        constructed by considering the points in this order.
+        The ``large`` option and ``initial_point`` is ignored in this case.
+        The ``point_order`` may contain only a subset of the points;
+        in this case, the dimension of the simplex will be the dimension of
+        this subset.
 
         EXAMPLES::
 
@@ -1857,13 +1867,18 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             (P(0, 1), P(2, 1), P(1, 0))
             sage: pc.contained_simplex(large=False)
             (P(0, 1), P(1, 1), P(1, 0))
-            sage: pc.contained_simplex(initial_point=pc.point(0))
-            (P(0, 0), P(1, 1), P(1, 0))
+            sage: pc.contained_simplex(initial_point=pc.point(2))
+            (P(2, 1), P(0, 0), P(1, 0))
 
             sage: pc = PointConfiguration([[0,0],[0,1],[1,0],[1,1],[-1,-1]])
             sage: pc.contained_simplex()
             (P(-1, -1), P(1, 1), P(0, 1))
-
+            sage: pc.contained_simplex(point_order = [pc[1],pc[3],pc[4],pc[2],pc[0]])
+            (P(0, 1), P(1, 1), P(-1, -1)) 
+            sage: # lower-dimensional example:
+            sage: pc.contained_simplex(point_order = [pc[0],pc[3],pc[4]])
+            (P(0, 0), P(1, 1))
+            
         TESTS::
 
             sage: pc = PointConfiguration([[0,0],[0,1],[1,0]])
@@ -1880,9 +1895,18 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             ()
         """
         self._assert_is_affine()
-        if self.n_points()==0:
+        if point_order is None:
+            points = list(self.points())
+        else:
+            points = list(reversed(point_order))
+            # points are removed one by one from the end.
+            initial_point = None
+            large = False
+            # If point_order is specified, the points of the
+            # PointConfiguration are actually ignored.
+        if not points:
             return tuple()
-        points = list(self.points())
+                         
         if initial_point is None:
             origin = points.pop()
         else:
@@ -1890,14 +1914,14 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             points.remove(origin)
         vertices = [origin]
         edges = []
-        while len(vertices) <= self.dim():
+        while points and len(vertices) <= self.dim():
             if large:
                 p = self.farthest_point(vertices, points)
                 points.remove(p)
             else:
                 p = points.pop()
             edge = p.reduced_affine_vector()-origin.reduced_affine_vector()
-            if len(edges)>0 and (ker * edge).is_zero():
+            if edges and (ker * edge).is_zero():
                 continue
             vertices.append(p)
             edges.append(edge)
@@ -1912,7 +1936,9 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
         INPUT:
 
         - ``point_order`` -- list of points or integers. The order in
-          which the points are to be placed.
+          which the points are to be placed. If not given, the points
+          will be placed in some arbitrary order that attempts to
+          produce a small number of simplices.
 
         OUTPUT:
 
@@ -1923,7 +1949,10 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             sage: pc = PointConfiguration([(0,0),(1,0),(2,1),(1,2),(0,1)])
             sage: pc.placing_triangulation()
             (<0,1,2>, <0,2,4>, <2,3,4>)
-
+            sage: pc.placing_triangulation(point_order=(3,2,1,4,0))
+            (<0,1,4>, <1,2,3>, <1,3,4>)
+            sage: pc.placing_triangulation(point_order=[pc[1],pc[3],pc[4],pc[0]])
+            (<0,1,4>, <1,3,4>)
             sage: U=matrix([
             ....:    [ 0, 0, 0, 0, 0, 2, 4,-1, 1, 1, 0, 0, 1, 0],
             ....:    [ 0, 0, 0, 1, 0, 0,-1, 0, 0, 0, 0, 0, 0, 0],
@@ -1941,6 +1970,15 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
              <3,4,6,7,11,12>, <3,4,7,11,12,13>, <3,6,7,11,12,13>, <4,6,7,11,12,13>)
             sage: sum(p.volume(t) for t in triangulation)
             42
+            sage: p0 = PointConfiguration([(0,0),(+1,0),(-1,0),(0,+1),(0,-1)])
+            sage: p0.pushing_triangulation(point_order=[1,2,0,3,4])
+            (<1,2,3>, <1,2,4>)
+            sage: p0.pushing_triangulation(point_order=[0,1,2,3,4])
+            (<0,1,3>, <0,1,4>, <0,2,3>, <0,2,4>)
+            sage: # the same triangulation with renumbered points 0->4, 1->0, etc.:
+            sage: p1 = PointConfiguration([(+1,0),(-1,0),(0,+1),(0,-1),(0,0)])
+            sage: p1.pushing_triangulation(point_order=[4,0,1,2,3])
+            (<0,2,4>, <0,3,4>, <1,2,4>, <1,3,4>)
         """
         facet_normals = dict()
         def facets_of_simplex(simplex):
@@ -1950,14 +1988,14 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             simplex = list(simplex)
             origin = simplex[0]
             rest = simplex[1:]
-            span = matrix([ origin.reduced_affine_vector()-p.reduced_affine_vector()
-                            for p in rest ])
+            span = matrix([origin.reduced_affine_vector()-p.reduced_affine_vector()
+                           for p in rest])
             # span.inverse() linearly transforms the simplex into the unit simplex
             normals = span.inverse().columns()
             facets = []
             # The facets incident to the chosen vertex "origin"
             for opposing_vertex, normal in zip(rest, normals):
-                facet = frozenset([origin] + [ p for p in rest if p is not opposing_vertex ])
+                facet = frozenset([origin] + [p for p in rest if p is not opposing_vertex])
                 facets.append(facet)
                 normal.set_immutable()
                 facet_normals[facet] = normal
@@ -1971,17 +2009,22 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
 
         # input verification
         self._assert_is_affine()
+        
+        point_order_is_given = point_order is not None
         if point_order is None:
             point_order = list(self.points())
         elif isinstance(point_order[0], Point):
             point_order = list(point_order)
-            assert all(p.point_configuration()==self for p in point_order)
+            assert all(p.point_configuration() is self for p in point_order),\
+                "Some point in 'point_order' does not belong to the PointConfiguration."
         else:
-            point_order = [ self.point(i) for i in point_order ]
-        assert all(p in self.points() for p in point_order)
+            point_order = [self.point(i) for i in point_order]
 
         # construct the initial simplex
-        simplices = [ frozenset(self.contained_simplex()) ]
+        if point_order_is_given:
+            simplices = [frozenset(self.contained_simplex(large=False, point_order = point_order))]
+        else:
+            simplices = [frozenset(self.contained_simplex(large=True))]
         for s in simplices[0]:
             try:
                 point_order.remove(s)
@@ -1990,6 +2033,10 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
         facets = facets_of_simplex(simplices[0])
 
         # successively place the remaining points
+
+        # TODO: In concordance with the heuristic to choose a LARGE starting simplex,
+        # one could continue to try to pick points that are far away from the previous ones,
+        # unless point_order_is_given.
         for point in point_order:
             # identify visible facets
             visible_facets = []
@@ -2015,7 +2062,7 @@ class PointConfiguration(UniqueRepresentation, PointConfiguration_base):
             facets.update(new_facets)
 
         # construct the triangulation
-        triangulation = [ [p.index() for p in simplex] for simplex in simplices ]
+        triangulation = [[p.index() for p in simplex] for simplex in simplices]
         return self(triangulation)
 
     pushing_triangulation = placing_triangulation
