@@ -394,7 +394,7 @@ class DiGraphGenerators():
 
         In this tournament there is an edge from `i` to `j` if `i<j`.
 
-        See :wikipedia:`Tournament_(graph_theory)`
+        See the :wikipedia:`Tournament_(graph_theory)` for more information.
 
         INPUT:
 
@@ -431,9 +431,7 @@ class DiGraphGenerators():
             for j in range(i+1, n):
                 g.add_edge(i, j)
 
-        if n:
-            from sage.graphs.graph_plot import _circle_embedding
-            _circle_embedding(g, list(range(n)))
+        g._circle_embedding(list(range(n)))
 
         return g
 
@@ -481,9 +479,7 @@ class DiGraphGenerators():
                 else:
                     g.add_edge(j, i)
 
-        if n:
-            from sage.graphs.graph_plot import _circle_embedding
-            _circle_embedding(g, list(range(n)))
+        g._circle_embedding(list(range(n)))
 
         return g
 
@@ -620,9 +616,7 @@ class DiGraphGenerators():
 
         G.add_edges((u,v) for u in range(n) for v in range(n) if u!=v)
 
-        if n:
-            from sage.graphs.graph_plot import _circle_embedding
-            _circle_embedding(G, list(range(n)))
+        G._circle_embedding(list(range(n)))
 
         return G
 
@@ -681,7 +675,6 @@ class DiGraphGenerators():
             ...
             ValueError: The list must contain only relative integers.
         """
-        from sage.graphs.graph_plot import _circle_embedding
         from sage.rings.integer_ring import ZZ
 
         # Bad input and loops
@@ -692,9 +685,9 @@ class DiGraphGenerators():
             if (i%n) == 0:
                 loops = True
 
-        G=DiGraph(n, name="Circulant graph ("+str(integers)+")", loops=loops)
+        G = DiGraph(n, name="Circulant graph ("+str(integers)+")", loops=loops)
 
-        _circle_embedding(G, list(range(n)))
+        G._circle_embedding(list(range(n)))
         for v in range(n):
             G.add_edges([(v,(v+j)%n) for j in integers])
 
@@ -710,8 +703,7 @@ class DiGraphGenerators():
 
         In this digraph, there is an arc `w_1w_2` if `w_2` can be obtained from
         `w_1` by removing the leftmost letter and adding a new letter at its
-        right end.  For more information, see the
-        :wikipedia:`Wikipedia article on De Bruijn graph <De_Bruijn_graph>`.
+        right end.  For more information, see the :wikipedia:`De_Bruijn_graph`.
 
         INPUT:
 
@@ -967,8 +959,7 @@ class DiGraphGenerators():
         digraph of Imase and Itoh [II83]_ of degree `d` and order
         `d^{D-1}(d+1)`.
 
-        See also the
-        :wikipedia:`Wikipedia article on Kautz Graphs <Kautz_graph>`.
+        See the :wikipedia:`Kautz_graph` for more information.
 
         INPUT:
 
@@ -1435,9 +1426,7 @@ class DiGraphGenerators():
             if coin>=2:
                 G.add_edge(v,u)
 
-        if n:
-            from sage.graphs.graph_plot import _circle_embedding
-            _circle_embedding(G, list(range(n)))
+        G._circle_embedding(list(range(n)))
 
         return G
 
