@@ -45,6 +45,7 @@ Some examples in the multiplicative group of a finite field:
 
 - Orders of elements::
 
+    sage: from sage.groups.generic import order_from_multiple, order_from_bounds
     sage: k.<a> = GF(5^5)
     sage: b = a^4
     sage: order_from_multiple(b,5^5-1,operation='*')
@@ -56,14 +57,14 @@ Some examples in the group of points of an elliptic curve over a finite field:
 
 - Discrete logs::
 
-    sage: F=GF(37^2,'a')
-    sage: E=EllipticCurve(F,[1,1])
-    sage: F.<a>=GF(37^2,'a')
-    sage: E=EllipticCurve(F,[1,1])
-    sage: P=E(25*a + 16 , 15*a + 7 )
+    sage: F = GF(37^2,'a')
+    sage: E = EllipticCurve(F,[1,1])
+    sage: F.<a> = GF(37^2,'a')
+    sage: E = EllipticCurve(F,[1,1])
+    sage: P = E(25*a + 16 , 15*a + 7 )
     sage: P.order()
     672
-    sage: Q=39*P; Q
+    sage: Q = 39*P; Q
     (36*a + 32 : 5*a + 12 : 1)
     sage: discrete_log(Q,P,P.order(),operation='+')
     39
@@ -81,6 +82,7 @@ Some examples in the group of points of an elliptic curve over a finite field:
 
 - Orders of elements::
 
+    sage: from sage.groups.generic import order_from_multiple, order_from_bounds
     sage: k.<a> = GF(5^5)
     sage: E = EllipticCurve(k,[2,4])
     sage: P = E(3*a^4 + 3*a , 2*a + 1 )
@@ -94,6 +96,16 @@ Some examples in the group of points of an elliptic curve over a finite field:
     7
     sage: order_from_bounds(Q, Hasse_bounds(5^5), operation='+')
     7
+
+TESTS:
+
+Check deprecation from :trac:`25785`::
+
+    sage: bsgs
+    doctest:warning...:
+    DeprecationWarning: this is being removed from the global namespace
+    See https://trac.sagemath.org/25785 for details.
+    ...
 """
 
 #*****************************************************************************
@@ -121,7 +133,6 @@ from sage.arith.srange import xsrange
 multiplication_names = ( 'multiplication', 'times', 'product', '*')
 addition_names       = ( 'addition', 'plus', 'sum', '+')
 
-
 # deprecation(24256)
 from sage.structure.element import generic_power as power
 
@@ -338,7 +349,6 @@ class multiples:
         self.bound = n
         self.indexed = indexed
 
-
     def __next__(self):
         """
         Returns the next item in this multiples iterator.
@@ -404,6 +414,7 @@ def bsgs(a, b, bounds, operation='*', identity=None, inverse=None, op=None):
 
     EXAMPLES::
 
+        sage: from sage.groups.generic import bsgs
         sage: b = Mod(2,37);  a = b^20
         sage: bsgs(b, a, (0,36))
         20
@@ -499,6 +510,7 @@ def bsgs(a, b, bounds, operation='*', identity=None, inverse=None, op=None):
 
     raise ValueError("Log of %s to the base %s does not exist in %s."%(b,a,bounds))
 
+
 def discrete_log_rho(a, base, ord=None, operation='*', hash_function=hash):
     """
     Pollard Rho algorithm for computing discrete logarithm in cyclic
@@ -664,6 +676,7 @@ def discrete_log_rho(a, base, ord=None, operation='*', hash_function=hash):
 
     raise ValueError("Pollard rho algorithm failed to find a logarithm")
 
+
 def discrete_log(a, base, ord=None, bounds=None, operation='*', identity=None, inverse=None, op=None):
     r"""
     Totally generic discrete log function.
@@ -828,12 +841,14 @@ def discrete_log(a, base, ord=None, bounds=None, operation='*', identity=None, i
     except ValueError:
         raise ValueError("No discrete log of %s found to base %s"%(a,base))
 
+
 def discrete_log_generic(a, base, ord=None, bounds=None, operation='*', identity=None, inverse=None, op=None):
     """
     Alias for ``discrete_log``.
     """
     return discrete_log(a, base, ord=None, bounds=None, operation='*', identity=None, inverse=None, op=None)
 
+
 def discrete_log_lambda(a, base, bounds, operation='*', hash_function=hash):
     """
     Pollard Lambda algorithm for computing discrete logarithms. It uses
@@ -941,6 +956,7 @@ def discrete_log_lambda(a, base, bounds, operation='*', hash_function=hash):
 #
 ################################################################
 
+
 def linear_relation(P, Q, operation='+', identity=None, inverse=None, op=None):
     r"""
     Function which solves the equation ``a*P=m*Q`` or ``P^a=Q^m``.
@@ -1040,6 +1056,7 @@ def linear_relation(P, Q, operation='+', identity=None, inverse=None, op=None):
 #
 ################################################################
 
+
 def order_from_multiple(P, m, plist=None, factorization=None, check=True,
                         operation='+'):
     r"""
@@ -1066,6 +1083,7 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
 
     EXAMPLES::
 
+        sage: from sage.groups.generic import order_from_multiple
         sage: k.<a> = GF(5^5)
         sage: b = a^4
         sage: order_from_multiple(b,5^5-1,operation='*')
@@ -1095,7 +1113,6 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
         sage: order_from_multiple(a, 3^60-1, operation='*', check=False)
         42391158275216203514294433200
     """
-    from operator import mul, add
     Z = integer_ring.ZZ
 
     if operation in multiplication_names:
@@ -1147,7 +1164,6 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
         else:
             # try to split the list wisely
             sum_left = 0
-            i = 0
             for k in range(l):
                 p,e = L[k]
                 # multiplying by p**e require roughly 'e log_2(p) / 2' additions
@@ -1171,8 +1187,6 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
     return _order_from_multiple_helper(P, F, sage.functions.log.log(float(M)) )
 
 
-
-
 def order_from_bounds(P, bounds, d=None, operation='+',
                          identity=None, inverse=None, op=None):
     r"""
@@ -1208,6 +1222,7 @@ def order_from_bounds(P, bounds, d=None, operation='+',
 
     EXAMPLES::
 
+        sage: from sage.groups.generic import order_from_bounds
         sage: k.<a> = GF(5^5)
         sage: b = a^4
         sage: order_from_bounds(b,(5^4,5^5),operation='*')
@@ -1228,7 +1243,6 @@ def order_from_bounds(P, bounds, d=None, operation='+',
 
     """
     from operator import mul, add
-    Z = integer_ring.ZZ
 
     if operation in multiplication_names:
         op = mul
@@ -1256,6 +1270,7 @@ def order_from_bounds(P, bounds, d=None, operation='+',
 
     return order_from_multiple(P, m, operation=operation, check=False)
 
+
 def merge_points(P1,P2, operation='+',
                          identity=None, inverse=None, op=None, check=True):
     r"""
@@ -1281,6 +1296,7 @@ def merge_points(P1,P2, operation='+',
 
     EXAMPLES::
 
+        sage: from sage.groups.generic import merge_points
         sage: F.<a>=GF(3^6,'a')
         sage: b = a^7
         sage: c = a^13
@@ -1308,7 +1324,6 @@ def merge_points(P1,P2, operation='+',
         True
     """
     from operator import mul, add
-    Z = integer_ring.ZZ
 
     g1, n1 = P1
     g2, n2 = P2
@@ -1340,6 +1355,7 @@ def merge_points(P1,P2, operation='+',
     g2 = multiple(g2,m2,operation=operation)
     return (op(g1,g2), m)
 
+
 def structure_description(G, latex=False):
     r"""
     Return a string that tries to describe the structure of ``G``.
@@ -1410,7 +1426,7 @@ def structure_description(G, latex=False):
 
     import re
     def correct_dihedral_degree(match):
-        return "%sD%d" % (match.group(1), int(match.group(2))/2)
+        return "%sD%d" % (match.group(1), int(match.group(2)) // 2)
 
     description = str(G._gap_().StructureDescription())
 
