@@ -54,7 +54,6 @@ from sage.rings.ring import is_Ring
 from sage.rings.finite_rings.finite_field_constructor import is_FiniteField
 from sage.matrix.matrix_space import MatrixSpace
 from sage.misc.latex import latex
-from sage.structure.sequence import Sequence
 from sage.structure.richcmp import (richcmp_not_equal, rich_to_bool,
                                     richcmp_method, richcmp)
 from sage.misc.cachefunc import cached_method
@@ -126,12 +125,14 @@ class MatrixGroup_base(Group):
 
         EXAMPLES::
 
-            sage: G = SU(2,GF(5))
-            sage: G._check_matrix(identity_matrix(GF(5),2))
-            sage: G._check_matrix(matrix(GF(5),[[1,1],[0,1]]))
+            sage: G = SU(2,GF(5)); F = G.base_ring() # this is GF(5^2,'a')
+            sage: G._check_matrix(identity_matrix(F,2))
+            sage: G._check_matrix(matrix(F,[[1,1],[0,1]]))
             Traceback (most recent call last):
             ...
-            TypeError: matrix must be unitary
+            TypeError: matrix must be unitary with respect to the hermitian form
+            [0 1]
+            [1 0]
         """
         if not x.is_invertible():
             raise TypeError('matrix is not invertible')
@@ -589,7 +590,7 @@ class MatrixGroup_gap(GroupMixinLibGAP, MatrixGroup_generic, ParentLibGAP):
             TypeError: matrix is not in the finitely generated group
         """
         from sage.libs.gap.libgap import libgap
-        libgap_contains = libgap.eval('\in')
+        libgap_contains = libgap.eval(r'\in')
         is_contained = libgap_contains(x_gap, self.gap())
         if not is_contained.sage():
             raise TypeError('matrix is not in the finitely generated group')
