@@ -192,7 +192,7 @@ class Octave(Expect):
         Expect.__init__(self,
                         name = 'octave',
                         # We want the prompt sequence to be unique to avoid confusion with syntax error messages containing >>>
-                        prompt = 'octave\:\d+> ',
+                        prompt = r'octave\:\d+> ',
                         # We don't want any pagination of output
                         command = command + " --no-line-editing --silent --eval 'PS2(PS1());more off' --persist",
                         maxread = maxread,
@@ -461,7 +461,7 @@ class Octave(Expect):
         octave_console()
 
     def version(self):
-        """
+        r"""
         Return the version of Octave.
 
         OUTPUT: string
@@ -473,7 +473,7 @@ class Octave(Expect):
             '2.13.7'
 
             sage: import re
-            sage: assert re.match("\d+\.\d+\.\d+", v)  is not None # optional - octave
+            sage: assert re.match(r"\d+\.\d+\.\d+", v)  is not None # optional - octave
         """
         return str(self("version")).strip()
 
