@@ -1066,22 +1066,22 @@ class ExpressionNice(Expression):
             # checking if the variable is composite
             for i, val in enumerate(strv):
                 if bool(re.search(r'[+|-|/|*|^|(|)]', val)):
-                    latv[i] = "\left(" + latv[i] + "\\right)"
+                    latv[i] = r"\left(" + latv[i] + r"\right)"
 
             # dictionary to group multiple occurrences of differentiation: d/dxdx -> d/dx^2 etc.
             occ = {i: (latv[i] + "^" + latex(diffargs.count(i))
                        if diffargs.count(i) > 1 else latv[i])
                    for i in diffargs}
 
-            res = "\\frac{\partial" + numargs + "\," + funcname + \
-                  "}{\partial " + "\partial ".join(i for i in occ.values()) + "}"
+            res = r"\frac{\partial" + numargs + r"\," + funcname + \
+                  r"}{\partial " + r"\partial ".join(i for i in occ.values()) + "}"
 
             # representation of the operator
             s = self._parent._latex_element_(m[0])
 
             # if diff operator is raised to some power (m[5]), put brackets around
             if m[5]:
-                res = "\left(" + res + "\\right)^{" + str(m[5]) + "}"
+                res = r"\left(" + res + r"\right)^{" + str(m[5]) + "}"
                 o = s + "^{" + str(m[5]) + "}"
             else:
                 o = s
