@@ -81,7 +81,7 @@ from sage.matroids.advanced import newlabel
 
 
 def it(M, B1, nB1, lps):
-    """
+    r"""
     Return points on and off the triangle and lines to be drawn for a rank 3
     matroid.
 
@@ -133,10 +133,8 @@ def it(M, B1, nB1, lps):
 
     .. NOTE::
 
-            This method does NOT do any checks.
-
+        This method does NOT do any checks.
     """
-
     tripts = [(0, 0), (1, 2), (2, 0)]
     pts = {}
     j = 0
@@ -241,7 +239,7 @@ def addnontripts(tripts_labels, nontripts_labels, ptsdict):
     OUTPUT:
 
     A dictionary containing ground set elements in ``tripts`` as keys and
-    their (x,y) position as values allong with all keys and respective values
+    their (x,y) position as values along with all keys and respective values
     in ``ptsdict``.
 
     EXAMPLES::
@@ -692,15 +690,13 @@ def posdict_is_sane(M1, pos_dict):
     pcls = list(set([frozenset(set(M1.closure([p])) - L) for p in list(P)]))
     for pcl in pcls:
         pcl_list = list(pcl)
-        if not any([x in pos_dict.keys() for x in pcl_list]):
+        if not any(x in pos_dict for x in pcl_list):
             return False
     allP = []
     for pcl in pcls:
             allP.extend(list(pcl))
-    if not all([x in pos_dict.keys()
-                for x in list(set(M1.groundset()) - (L | set(allP)))]):
-            return False
-    return True
+    return all(x in pos_dict
+               for x in list(set(M1.groundset()) - (L | set(allP))))
 
 
 def tracklims(lims, x_i=[], y_i=[]):
@@ -855,8 +851,8 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
         ptsx, ptsy, x_i, y_i = createline(pts2, bline, lineorders1)
         lims = tracklims(lims, x_i, y_i)
         G += line(zip(x_i, y_i), color='black', thickness=3, zorder=1)
-        pels = [p for p in pts2.keys() if any([M1.rank([p, q]) == 1
-                for q in P])]
+        pels = [p for p in pts2
+                if any(M1.rank([p, q]) == 1 for q in P)]
         allpts = [list(pts2[i]) for i in M.groundset()]
         xpts = [float(k[0]) for k in allpts]
         ypts = [float(k[1]) for k in allpts]
@@ -891,8 +887,8 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
                 ptsx, ptsy, x_i, y_i = createline(pts2, ll, lineorders1)
                 lims = tracklims(lims, x_i, y_i)
                 G += line(zip(x_i, y_i), color='black', thickness=3, zorder=1)
-        pels = [p for p in pts2.keys() if any([M1.rank([p, q]) == 1
-                for q in P])]
+        pels = [p for p in pts2
+                if any(M1.rank([p, q]) == 1 for q in P)]
         allpts = [list(pts2[i]) for i in M.groundset()]
         xpts = [float(k[0]) for k in allpts]
         ypts = [float(k[1]) for k in allpts]
