@@ -2,17 +2,17 @@ from __future__ import absolute_import
 from .lazy_attribute import lazy_attribute, lazy_class_attribute
 from .lazy_import import lazy_import
 
-from .misc import (BackslashOperator, getitem,
+from .misc import (BackslashOperator,
                   cputime, verbose, set_verbose, set_verbose_files,
                   get_verbose_files, unset_verbose_files, get_verbose,
                   union, uniq, powerset, subsets,
                   exists, forall, is_iterator,
-                  random_sublist, walltime, generic_cmp,
+                  random_sublist, walltime,
                   repr_lincomb,
                   pad_zeros, attrcall,
                   SAGE_DB, SAGE_TMP,
-                  newton_method_sizes, compose,
-                  self_compose, nest)
+                   newton_method_sizes, compose,
+                  nest)
 
 from .banner import version, banner
 
