@@ -20,10 +20,22 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import print_function, absolute_import
+
+import os
+import random
+import re
+import shutil
+import subprocess
+
 from six import iteritems, integer_types
 
 from sage.cpython.string  import str_to_bytes
 
+from sage.misc import sage_eval
+from sage.misc.cachefunc import cached_function, cached_method
+from sage.misc.sage_ostools import have_program
+from sage.misc.temporary_file import tmp_dir
+
 EMBEDDED_MODE = False
 
 COMMON_HEADER = \
@@ -56,15 +68,6 @@ r'''\textwidth=1.1\textwidth
 \textheight=2\textheight
 ''')
 
-import shutil, re
-import os.path
-import random
-import subprocess
-
-from sage.misc.temporary_file import tmp_dir
-from . import sage_eval
-from sage.misc.sage_ostools import have_program
-from sage.misc.cachefunc import cached_function, cached_method
 
 @cached_function
 def have_latex():
@@ -258,8 +261,9 @@ def builtin_constant_function(x):
         sage: sage.misc.latex.EMBEDDED_MODE = False
     """
     if EMBEDDED_MODE:
-        return "{\\rm %s}"%x
-    return "\mbox{\\rm %s}"%x
+        return "{\\rm %s}" % x
+    return "\\mbox{\\rm %s}" % x
+
 
 def None_function(x):
     r"""
@@ -329,7 +333,7 @@ def str_function(x):
         return x
     # Deal with special characters
     char_wrapper = r"{\char`\%s}"
-    x = "".join(char_wrapper % c if c in "#$%&\^_{}~" else c for c in x)
+    x = "".join(char_wrapper % c if c in r"#$%&\^_{}~" else c for c in x)
     # Avoid grouping spaces into one
     x = x.replace(" ", "{ }")
     # And dashes too, since it causes issues for the command line...
@@ -864,8 +868,9 @@ def _run_latex_(filename, debug=False, density=150, engine=None, png=False, do_i
         return "Error latexing slide."
     return return_suffix
 
+
 class LatexCall:
-    """
+    r"""
     Typeset Sage objects via a ``__call__`` method to this class,
     typically by calling those objects' ``_latex_`` methods.  The
     class :class:`Latex` inherits from this. This class is used in
@@ -1772,7 +1777,7 @@ def _latex_file_(objects, title='SAGE', debug=False, \
                 s += '%s'%L
                 s += r'\end{lrbox}'
                 s += r'\resizebox{\ifdim\width>\textwidth\textwidth\else\width\fi}{!}{\usebox{\pgffigure}}' + '\n'
-            elif not '\\begin{verbatim}' in L:
+            elif '\\begin{verbatim}' not in L:
                 s += '%s%s%s'%(math_left, L, math_right)
             else:
                 s += '%s'%L
@@ -1940,8 +1945,10 @@ class MathJax:
             <html><script type="math/tex; mode=display">\newcommand{\Bold}[1]{\mathbf{#1}}3</script></html>
             sage: MathJax().eval(3, mode='inline')
             <html><script type="math/tex">\newcommand{\Bold}[1]{\mathbf{#1}}3</script></html>
-            sage: MathJax().eval(type(3), mode='inline')
+            sage: MathJax().eval(type(3), mode='inline')  # py2
             <html><script type="math/tex">\newcommand{\Bold}[1]{\mathbf{#1}}\verb|<type|\phantom{\verb!x!}\verb|'sage.rings.integer.Integer'>|</script></html>
+            sage: MathJax().eval(type(3), mode='inline')  # py3
+            <html><script type="math/tex">\newcommand{\Bold}[1]{\mathbf{#1}}\verb|<class|\phantom{\verb!x!}\verb|'sage.rings.integer.Integer'>|</script></html>
         """
         # Get a regular LaTeX representation of x
         x = latex(x, combine_all=combine_all)
@@ -1963,7 +1970,7 @@ class MathJax:
             # part should end in "}}", so omit the last two characters
             # from y
             y = part[:closing-1]
-            for delimiter in """|"'`#%&,.:;?!@_~^+-/\=<>()[]{}0123456789E""":
+            for delimiter in r"""|"'`#%&,.:;?!@_~^+-/\=<>()[]{}0123456789E""":
                 if delimiter not in y:
                     break
             if delimiter == "E":
@@ -2419,7 +2426,7 @@ def repr_lincomb(symbols, coeffs):
                 # multiplication sign in
                 try:
                     if bv in CC:
-                        s += "%s\cdot %s" % (coeff, b)
+                        s += r"%s\cdot %s" % (coeff, b)
                     else:
                         s += "%s%s" % (coeff, b)
                 except Exception:
@@ -2614,7 +2621,7 @@ def latex_variable_name(x, is_fname=False):
         # * The "\d|[.,]" means "decimal digit" or period or comma
         # * The "+" means "1 or more"
         # * The "$" means "at the end of the line"
-        m = re.search('(\d|[.,])+$',x)
+        m = re.search(r'(\d|[.,])+$', x)
         if m is None:
             prefix = x
             suffix = None
@@ -2629,15 +2636,16 @@ def latex_variable_name(x, is_fname=False):
             for sym in symtable.values():
                 if sym[0] == '_' and sym[1:] == suffix:
                     return latex_variable_name(suffix)
-    if suffix and len(suffix) > 0:
+    if suffix and len(suffix):
         # handle the suffix specially because it very well might be numeric
         # I use strip to avoid using regex's -- It makes it a bit faster (and the code is more comprehensible to non-regex'ed people)
-        if suffix.strip("1234567890")!="":
+        if suffix.strip("1234567890") != "":
             suffix = latex_variable_name(suffix, is_fname) # recurse to deal with recursive subscripts
-        return '%s_{%s}'%(latex_varify(prefix, is_fname), suffix)
+        return '%s_{%s}' % (latex_varify(prefix, is_fname), suffix)
     else:
         return latex_varify(prefix, is_fname)
 
+
 class LatexExamples():
     r"""
     A catalogue of Sage objects with complicated ``_latex_`` methods.
@@ -2674,18 +2682,6 @@ class LatexExamples():
             LaTeX example for testing display of graphs...
         """
 
-        def __init__(self):
-            """
-            See the string representation for complete documentation.
-
-            EXAMPLES::
-
-                sage: from sage.misc.latex import latex_examples
-                sage: type(latex_examples.graph())
-                <class 'sage.misc.latex.graph'>
-            """
-            pass
-
         def _repr_(self):
             """
             String representation
@@ -2755,17 +2751,6 @@ from the notebook -- you should get a nice picture.
             sage: PS
             LaTeX example for testing display of pstricks...
         """
-        def __init__(self):
-            """
-            See the string representation for complete documentation.
-
-            EXAMPLES::
-
-                sage: from sage.misc.latex import latex_examples
-                sage: type(latex_examples.pstricks())
-                <class 'sage.misc.latex.pstricks'>
-            """
-            pass
 
         def _repr_(self):
             """
@@ -2826,17 +2811,6 @@ should get a nice picture."""
             sage: K
             LaTeX example for testing display of a knot...
         """
-        def __init__(self):
-            """
-            See the string representation for complete documentation.
-
-            EXAMPLES::
-
-                sage: from sage.misc.latex import latex_examples
-                sage: type(latex_examples.knot())
-                <class 'sage.misc.latex.knot'>
-            """
-            pass
 
         def _repr_(self):
             """
@@ -2889,17 +2863,6 @@ should get a nice picture.
             sage: CD
             LaTeX example for testing display of a commutative diagram...
         """
-        def __init__(self):
-            """
-            See the string representation for complete documentation.
-
-            EXAMPLES::
-
-                sage: from sage.misc.latex import latex_examples
-                sage: type(latex_examples.diagram())
-                <class 'sage.misc.latex.diagram'>
-            """
-            pass
 
         def _repr_(self):
             """
