@@ -28,7 +28,7 @@ Check the fix from :trac:`8323`::
     False
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2006 William Stein <wstein@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -36,7 +36,7 @@ Check the fix from :trac:`8323`::
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #                  http://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 from __future__ import print_function, absolute_import
 from six.moves import range
 from six import integer_types
@@ -46,18 +46,21 @@ import stat
 import sys
 import time
 import resource
-import sage.misc.prandom as random
+import pdb
 import warnings
+import sage.misc.prandom as random
 from .lazy_string import lazy_string
+import sage.server.support
 
 from sage.env import DOT_SAGE, HOSTNAME
 
-LOCAL_IDENTIFIER = '%s.%s'%(HOSTNAME , os.getpid())
+LOCAL_IDENTIFIER = '%s.%s' % (HOSTNAME, os.getpid())
 
 #################################################################
 # File and directory utilities
 #################################################################
 
+
 def sage_makedirs(dir):
     """
     Python version of ``mkdir -p``: try to create a directory, and also
@@ -113,6 +116,105 @@ if hasattr(os, 'chmod'):
             print("Setting permissions of DOT_SAGE directory so only you "
                   "can read and write it.")
 
+def try_read(obj, splitlines=False):
+    r"""
+    Determine if a given object is a readable file-like object and if so
+    read and return its contents.
+
+    That is, the object has a callable method named ``read()`` which takes
+    no arguments (except ``self``) then the method is executed and the
+    contents are returned.
+
+    Alternatively, if the ``splitlines=True`` is given, first ``splitlines()``
+    is tried, then if that fails ``read().splitlines()``.
+
+    If either method fails, ``None`` is returned.
+
+    INPUT:
+
+    - ``obj`` -- typically a `file` or `io.BaseIO` object, but any other
+      object with a ``read()`` method is accepted.
+
+    - ``splitlines`` -- `bool`, optional; if True, return a list of lines
+      instead of a string.
+
+    EXAMPLES::
+
+        sage: import io
+        sage: filename = tmp_filename()
+        sage: from sage.misc.misc import try_read
+        sage: with open(filename, 'w') as fobj:
+        ....:     _ = fobj.write('a\nb\nc')
+        sage: with open(filename) as fobj:
+        ....:     print(try_read(fobj))
+        a
+        b
+        c
+        sage: with open(filename) as fobj:
+        ....:     try_read(fobj, splitlines=True)
+        ['a\n', 'b\n', 'c']
+
+    The following example is identical to the above example on Python 3,
+    but different on Python 2 where ``open != io.open``::
+
+        sage: with io.open(filename) as fobj:
+        ....:     print(try_read(fobj))
+        a
+        b
+        c
+
+    I/O buffers::
+
+        sage: buf = io.StringIO(u'a\nb\nc')
+        sage: print(try_read(buf))
+        a
+        b
+        c
+        sage: _ = buf.seek(0); try_read(buf, splitlines=True)
+        [u'a\n', u'b\n', u'c']
+        sage: buf = io.BytesIO(b'a\nb\nc')
+        sage: try_read(buf) == b'a\nb\nc'
+        True
+        sage: _ = buf.seek(0)
+        sage: try_read(buf, splitlines=True) == [b'a\n', b'b\n', b'c']
+        True
+
+    Custom readable::
+
+        sage: class MyFile(object):
+        ....:     def read(self): return 'Hello world!'
+        sage: try_read(MyFile())
+        'Hello world!'
+        sage: try_read(MyFile(), splitlines=True)
+        ['Hello world!']
+
+    Not readable::
+
+        sage: try_read(1) is None
+        True
+    """
+
+    if splitlines:
+        try:
+            return obj.readlines()
+        except (AttributeError, TypeError):
+            pass
+
+    try:
+        data = obj.read()
+    except (AttributeError, TypeError):
+        return
+
+    if splitlines:
+        try:
+            data = data.splitlines()
+        except (AttributeError, TypeError):
+            # Not a string??
+            data = [data]
+
+    return data
+
+
 
 #################################################
 # Next we create the Sage temporary directory.
@@ -174,6 +276,7 @@ def SAGE_TMP_INTERFACE():
     sage_makedirs(d)
     return d
 
+
 SAGE_DB = os.path.join(DOT_SAGE, 'db')
 sage_makedirs(SAGE_DB)
 
@@ -183,19 +286,11 @@ try:
 except KeyError:
     pass
 
-#################################################################
-# Functions to help with interfacing with CXX code that
-# uses the GMP library
-#################################################################
-def to_gmp_hex(n):
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "to_gmp_hex() is deprecated")
-    return hex(n).replace("L","").replace("0x","")
-
 #################################################################
 # timing
 #################################################################
 
+
 def cputime(t=0, subprocesses=False):
     """
     Return the time in CPU seconds since Sage started, or with
@@ -250,15 +345,15 @@ def cputime(t=0, subprocesses=False):
         started and terminated at any given time.
     """
     if isinstance(t, GlobalCputime):
-        subprocesses=True
+        subprocesses = True
 
     if not subprocesses:
         try:
             t = float(t)
         except TypeError:
             t = 0.0
-        u,s = resource.getrusage(resource.RUSAGE_SELF)[:2]
-        return u+s - t
+        u, s = resource.getrusage(resource.RUSAGE_SELF)[:2]
+        return u + s - t
     else:
         if t == 0:
             ret = GlobalCputime(cputime())
@@ -287,6 +382,7 @@ def cputime(t=0, subprocesses=False):
                         pass
             return ret
 
+
 class GlobalCputime:
     """
     Container for CPU times of subprocesses.
@@ -390,6 +486,7 @@ class GlobalCputime:
         """
         return float(self.total)
 
+
 def walltime(t=0):
     """
     Return the wall time in second, or with optional argument t, return
@@ -419,10 +516,11 @@ def walltime(t=0):
 #################################################################
 # simple verbosity system
 #################################################################
-LEVEL=0  # default
+LEVEL = 0  # default
 
 verbose_files = []
 
+
 def verbose(mesg="", t=0, level=1, caller_name=None):
     """
     Print a message if the current verbosity is at least level.
@@ -455,13 +553,13 @@ def verbose(mesg="", t=0, level=1, caller_name=None):
         VERBOSE1 (william): This is Sage. (time = 0.0)
         sage: set_verbose(0)
     """
-    if level>LEVEL:
+    if level > LEVEL:
         return cputime()
 
     frame = sys._getframe(1).f_code
     file_name = frame.co_filename
     lineno = frame.co_firstlineno
-    if 'all' in verbose_files or level<=0:
+    if 'all' in verbose_files or level <= 0:
         show = True
     else:
         show = False
@@ -473,7 +571,7 @@ def verbose(mesg="", t=0, level=1, caller_name=None):
     if not show:
         return cputime()
 
-    if t != 0 and mesg=="":
+    if t != 0 and mesg == "":
         mesg = "Finished."
 
     # see recipe 14.7 in Python Cookbook
@@ -483,20 +581,16 @@ def verbose(mesg="", t=0, level=1, caller_name=None):
             caller_name = ""
     short_file_name = os.path.split(frame.co_filename)[1]
     if '<' in short_file_name and '>' in short_file_name:
-        s = "verbose %s (%s) %s"%(level, caller_name, mesg)
+        s = "verbose %s (%s) %s" % (level, caller_name, mesg)
     else:
-        s = "verbose %s (%s: %s, %s) %s"%(level, lineno, short_file_name, caller_name, mesg)
-    if t!=0:
-        s = s + " (time = %s)"%cputime(t)
+        s = "verbose %s (%s: %s, %s) %s" % (level, lineno,
+                                            short_file_name, caller_name, mesg)
+    if t != 0:
+        s = s + " (time = %s)" % cputime(t)
     print(s)
     sys.stdout.flush()
     return cputime()
 
-def todo(mesg=""):
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "todo() is deprecated")
-    caller_name = sys._getframe(1).f_code.co_name
-    raise NotImplementedError("{}: todo -- {}".format(caller_name, mesg))
 
 def set_verbose(level, files='all'):
     """
@@ -531,6 +625,7 @@ def set_verbose(level, files='all'):
         files = [files]
     set_verbose_files(files)
 
+
 def set_verbose_files(file_name):
     """
 
@@ -540,12 +635,14 @@ def set_verbose_files(file_name):
     global verbose_files
     verbose_files = file_name
 
+
 def get_verbose_files():
     """
 
     """
     return verbose_files
 
+
 def unset_verbose_files(file_name):
     """
 
@@ -577,23 +674,6 @@ def get_verbose():
     return LEVEL
 
 
-
-def generic_cmp(x,y):
-    """
-    Compare x and y and return -1, 0, or 1.
-
-    This is similar to x.__cmp__(y), but works even in some cases
-    when a .__cmp__ method is not defined.
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "generic_cmp() is deprecated")
-    if x < y:
-        return -1
-    elif x == y:
-        return 0
-    return 1
-
-
 def cmp_props(left, right, props):
     from sage.misc.superseded import deprecation
     deprecation(23149, "cmp_props is deprecated")
@@ -637,6 +717,7 @@ def union(x, y=None):
         return list(set(x))
     return list(set(x).union(y))
 
+
 def uniq(x):
     """
     Return the sublist of all elements in the list x that is sorted and
@@ -665,15 +746,17 @@ def coeff_repr(c, is_latex=False):
     if is_latex and hasattr(c, '_latex_'):
         s = c._latex_()
     else:
-        s = str(c).replace(' ','')
+        s = str(c).replace(' ', '')
     if s.find("+") != -1 or s.find("-") != -1:
         if is_latex:
-            return "\\left(%s\\right)"%s
+            return "\\left(%s\\right)" % s
         else:
-            return "(%s)"%s
+            return "(%s)" % s
     return s
 
-def repr_lincomb(terms, is_latex=False, scalar_mult="*", strip_one=False, repr_monomial = None, latex_scalar_mult = None):
+
+def repr_lincomb(terms, is_latex=False, scalar_mult="*", strip_one=False,
+                 repr_monomial=None, latex_scalar_mult=None):
     """
     Compute a string representation of a linear combination of some
     formal symbols.
@@ -760,7 +843,9 @@ def repr_lincomb(terms, is_latex=False, scalar_mult="*", strip_one=False, repr_m
 
     if repr_monomial is None:
         if is_latex:
-            repr_monomial = lambda monomial: monomial._latex_() if hasattr(monomial, '_latex_') else str(monomial)
+
+            def repr_monomial(monomial):
+                return monomial._latex_() if hasattr(monomial, '_latex_') else str(monomial)
         else:
             repr_monomial = str
 
@@ -770,11 +855,11 @@ def repr_lincomb(terms, is_latex=False, scalar_mult="*", strip_one=False, repr_m
     if scalar_mult is None:
         scalar_mult = "" if is_latex else "*"
 
-    for (monomial,c) in terms:
+    for (monomial, c) in terms:
         if c != 0:
             coeff = coeff_repr(c)
             negative = False
-            if len(coeff)>0 and coeff[0] == "-":
+            if len(coeff) and coeff[0] == "-":
                 negative = True
             try:
                 if c < 0:
@@ -791,32 +876,33 @@ def repr_lincomb(terms, is_latex=False, scalar_mult="*", strip_one=False, repr_m
             if coeff != "0":
                 if negative:
                     if first:
-                        sign = "-" # add trailing space?
+                        sign = "-"  # add trailing space?
                     else:
                         sign = " - "
                 else:
                     if first:
                         sign = ""
                     else:
-                        sign= " + "
+                        sign = " + "
                 b = repr_monomial(monomial)
-                if len(b) > 0:
-                    if  coeff != "":
-                        if b =="1" and strip_one:
+                if len(b):
+                    if coeff != "":
+                        if b == "1" and strip_one:
                             b = ""
                         else:
                             b = scalar_mult + b
-                s += "%s%s%s"%(sign, coeff, b)
+                s += "%s%s%s" % (sign, coeff, b)
                 first = False
     if first:
-        return "0" # this can happen only if are only terms with coeff_repr(c) == "0"
-    #elif s == "":
-        #return "1" # is empty string representation invalid?
+        return "0"
+        # this can happen only if are only terms with coeff_repr(c) == "0"
+    # elif s == "":
+        # return "1"  # is empty string representation invalid?
     else:
         return s
 
 
-def strunc(s, n = 60):
+def strunc(s, n=60):
     """
     Truncate at first space after position n, adding '...' if
     nontrivial truncation.
@@ -828,11 +914,9 @@ def strunc(s, n = 60):
         while i < len(s) and s[i] != ' ':
             i += 1
         return s[:i] + " ..."
-        #return s[:n-4] + " ..."
     return s
 
 
-
 def newton_method_sizes(N):
     r"""
     Returns a sequence of integers
@@ -884,26 +968,8 @@ def newton_method_sizes(N):
 #################################################################
 
 
-def assert_attribute(x, attr, init=None):
-    """
-    If the object x has the attribute attr, do nothing. If not, set
-    x.attr to init.
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "assert_attribute() is deprecated")
-    if attr in x.__dict__: return
-    if attr[:2] == "__":
-        z = str(x.__class__).split("'")
-        if len(z) > 1:
-            z = z[1]
-        else:
-            z = z[0]
-        attr = "_" + z[len(x.__module__)+1:] + attr
-    x.__dict__[attr] = init
-
-
 def compose(f, g):
-    """
+    r"""
     Return the composition of one-variable functions: `f \circ g`
 
     See also :func:`nest()`
@@ -938,56 +1004,6 @@ def compose(f, g):
     return lambda x: f(g(x))
 
 
-def self_compose(f, n):
-    """
-    Return the function `f` composed with itself `n` times.
-
-    See :func:`nest()` if you want `f(f(...(f(x))...))` for
-    known `x`.
-
-
-    INPUT:
-        - `f` -- a function of one variable
-        - `n` -- a nonnegative integer
-
-    OUTPUT:
-        A function, the result of composing `f` with itself `n` times
-
-    EXAMPLES::
-
-        sage: def f(x): return x^2 + 1
-        sage: g = self_compose(f, 3)
-        doctest:... DeprecationWarning: self_compose() is deprecated, use nest() instead
-        See http://trac.sagemath.org/21926 for details.
-        sage: x = var('x')
-        sage: g(x)
-        ((x^2 + 1)^2 + 1)^2 + 1
-
-    ::
-
-        sage: def f(x): return x + 1
-        sage: g = self_compose(f, 10000)
-        sage: g(0)
-        10000
-
-    ::
-
-        sage: x = var('x')
-        sage: self_compose(sin, 0)(x)
-        x
-
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "self_compose() is deprecated, use nest() instead")
-    from sage.rings.all import Integer
-    n = Integer(n)
-
-    if n < 0:
-        raise ValueError("n must be a nonnegative integer, not {}.".format(n))
-
-    return lambda x: nest(f, n, x)
-
-
 def nest(f, n, x):
     """
     Return `f(f(...f(x)...))`, where the composition occurs n times.
@@ -1040,27 +1056,27 @@ def nest(f, n, x):
 #################################################################
 
 class BackslashOperator:
-    """
+    r"""
     Implements Matlab-style backslash operator for solving systems::
 
-        A \\ b
+        A \ b
 
     The preparser converts this to multiplications using
     ``BackslashOperator()``.
 
     EXAMPLES::
 
-        sage: preparse("A \ matrix(QQ,2,1,[1/3,'2/3'])")
+        sage: preparse("A \\ matrix(QQ,2,1,[1/3,'2/3'])")
         "A  * BackslashOperator() * matrix(QQ,Integer(2),Integer(1),[Integer(1)/Integer(3),'2/3'])"
-        sage: preparse("A \ matrix(QQ,2,1,[1/3,2*3])")
+        sage: preparse("A \\ matrix(QQ,2,1,[1/3,2*3])")
         'A  * BackslashOperator() * matrix(QQ,Integer(2),Integer(1),[Integer(1)/Integer(3),Integer(2)*Integer(3)])'
-        sage: preparse("A \ B + C")
+        sage: preparse("A \\ B + C")
         'A  * BackslashOperator() * B + C'
-        sage: preparse("A \ eval('C+D')")
+        sage: preparse("A \\ eval('C+D')")
         "A  * BackslashOperator() * eval('C+D')"
-        sage: preparse("A \ x / 5")
+        sage: preparse("A \\ x / 5")
         'A  * BackslashOperator() * x / Integer(5)'
-        sage: preparse("A^3 \ b")
+        sage: preparse("A^3 \\ b")
         'A**Integer(3)  * BackslashOperator() * b'
     """
     def __rmul__(self, left):
@@ -1080,7 +1096,7 @@ class BackslashOperator:
         return self
 
     def __mul__(self, right):
-        """
+        r"""
         EXAMPLES::
 
             sage: A = matrix(RDF, 5, 5, 2)
@@ -1115,19 +1131,29 @@ def is_iterator(it):
         sage: is_iterator(it)
         True
 
-        sage: class wrong():
+        sage: class wrong():  # py2
         ....:    def __init__(self): self.n = 5
         ....:    def next(self):
         ....:        self.n -= 1
         ....:        if self.n == 0: raise StopIteration
         ....:        return self.n
+        sage: class wrong():  # py3
+        ....:    def __init__(self): self.n = 5
+        ....:    def __next__(self):
+        ....:        self.n -= 1
+        ....:        if self.n == 0: raise StopIteration
+        ....:        return self.n
         sage: x = wrong()
         sage: is_iterator(x)
         False
-        sage: list(x)
+        sage: list(x)  # py2
         Traceback (most recent call last):
         ...
         TypeError: iteration over non-sequence
+        sage: list(x)  # py3
+        Traceback (most recent call last):
+        ...
+        TypeError: 'wrong' object is not iterable
 
         sage: class good(wrong):
         ....:    def __iter__(self): return self
@@ -1236,6 +1262,7 @@ def some_tuples(elements, repeat, bound, max_samples=None):
             return elements if repeat is None else product(elements, repeat=repeat)
         return _some_tuples_sampling(elements, repeat, max_samples, n)
 
+
 def _some_tuples_sampling(elements, repeat, max_samples, n):
     """
     Internal function for :func:`some_tuples`.
@@ -1257,6 +1284,7 @@ def _some_tuples_sampling(elements, repeat, max_samples, n):
         else:
             yield tuple(elements[j] for j in Integer(a).digits(n, padto=repeat))
 
+
 def powerset(X):
     r"""
     Iterator over the *list* of all subsets of the iterable X, in no
@@ -1293,7 +1321,7 @@ def powerset(X):
     You may also use subsets as an alias for powerset::
 
         sage: subsets([1,2,3])
-        <generator object powerset at 0x...>
+        <generator object ...powerset at 0x...>
         sage: list(subsets([1,2,3]))
         [[], [1], [2], [1, 2], [3], [1, 3], [2, 3], [1, 2, 3]]
 
@@ -1301,7 +1329,6 @@ def powerset(X):
         sets must be hashable and many structures on which one wants the
         powerset consist of non-hashable objects.
 
-
     AUTHORS:
 
     - William Stein
@@ -1312,68 +1339,13 @@ def powerset(X):
     yield []
     pairs = []
     for x in X:
-        pairs.append((2**len(pairs),x))
+        pairs.append((2**len(pairs), x))
         for w in range(2**(len(pairs)-1), 2**(len(pairs))):
             yield [x for m, x in pairs if m & w]
 
+
 subsets = powerset
 
-#################################################################
-# Type checking
-#################################################################
-def typecheck(x, C, var="x"):
-    """
-    Check that x is of instance C. If not raise a TypeError with an
-    error message.
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "typecheck is deprecated, use isinstance instead")
-    if not isinstance(x, C):
-        raise TypeError("{} (={}) must be of type {}.".format(var, x, C))
-
-#################################################################
-# This will likely eventually be useful.
-#################################################################
-
-# From the Python Cookbook Ver 2, Recipe 20.4
-class cached_attribute(object):
-    """
-    Computes attribute value and caches it in the instance.
-    """
-    def __init__(self, method, name=None):
-        from sage.misc.superseded import deprecation
-        deprecation(21926, "cached_attribute is deprecated")
-        # record the unbound-method and the name
-        self.method = method
-        self.name = name or method.__name__
-    def __get__(self, inst, cls):
-        if inst is None:
-            # instance attribute accessed on class, return self
-            return self
-        # compute, cache and return the instance's attribute value
-        result = self.method(inst)
-        setattr(inst, self.name, result)
-        return result
-
-class lazy_prop(object):
-    def __init__(self, calculate_function):
-        from sage.misc.superseded import deprecation
-        deprecation(21926, "lazy_prop is deprecated")
-        self._calculate = calculate_function
-        self.__doc__ = calculate_function.__doc__
-
-    def __call__(self, obj, _=None):
-        if obj is None:
-            return self
-        value = self._calculate(obj)
-        setattr(obj, self._calculate.__name__, value)
-        return value
-
-def prop(f):
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "prop() is deprecated")
-    return property(f, None, None, f.__doc__)
-
 
 #################################################################
 # Misc.
@@ -1426,9 +1398,11 @@ def exists(S, P):
         (False, None)
     """
     for x in S:
-        if P(x): return True, x
+        if P(x):
+            return True, x
     return False, None
 
+
 def forall(S, P):
     """
     If P(x) is true every x in S, return True and None. If there is
@@ -1483,30 +1457,17 @@ def forall(S, P):
         (True, None)
     """
     for x in S:
-        if not P(x): return False, x
+        if not P(x):
+            return False, x
     return True, None
 
-#################################################################
-# which source file?
-#################################################################
-import inspect
-def sourcefile(object):
-    """
-    Work out which source or compiled file an object was defined in.
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "sourcefile(x) is deprecated, use inspect.getfile(x) instead")
-    return inspect.getfile(object)
-
 
 #################################################################
 # debug tracing
 #################################################################
-import pdb
 set_trace = pdb.set_trace
 
 
-
 #################################################################
 # Word wrap lines
 #################################################################
@@ -1529,7 +1490,7 @@ def word_wrap(s, ncols=85):
                 end = ''
             t.append(x[:k] + end)
             x = x[k:]
-            k=0
+            k = 0
             while k < len(x) and x[k] == ' ':
                 k += 1
             x = x[k:]
@@ -1537,42 +1498,6 @@ def word_wrap(s, ncols=85):
     return '\n'.join(t)
 
 
-def getitem(v, n):
-    r"""
-    Variant of getitem that coerces to an int if a TypeError is
-    raised.
-
-    (This is not needed anymore - classes should define an
-    __index__ method.)
-
-    Thus, e.g., ``getitem(v,n)`` will work even if
-    `v` is a Python list and `n` is a Sage integer.
-
-    EXAMPLES::
-
-        sage: v = [1,2,3]
-
-    The following used to fail in Sage <= 1.3.7. Now it works fine::
-
-        sage: v[ZZ(1)]
-        2
-
-    This always worked.
-
-    ::
-
-        sage: getitem(v, ZZ(1))
-        doctest:... DeprecationWarning: getitem(v, n) is deprecated, use v[n] instead
-        See http://trac.sagemath.org/21926 for details.
-        2
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(21926, "getitem(v, n) is deprecated, use v[n] instead")
-    try:
-        return v[n]
-    except TypeError:
-        return v[int(n)]
-
 def pad_zeros(s, size=3):
     """
     EXAMPLES::
@@ -1588,9 +1513,8 @@ def pad_zeros(s, size=3):
         sage: pad_zeros(389, 10)
         '0000000389'
     """
-    return "0"*(size-len(str(s))) + str(s)
+    return "0" * (size - len(str(s))) + str(s)
 
-import sage.server.support
 
 def embedded():
     """
@@ -1641,8 +1565,9 @@ class AttrCallObject(object):
 
     def __repr__(self):
         """
-        Returns a string representation of this object. The star in the
-        output represents the object passed into self.
+        Return a string representation of this object.
+
+        The star in the output represents the object passed into ``self``.
 
         EXAMPLES::
 
@@ -1653,11 +1578,11 @@ class AttrCallObject(object):
             sage: attrcall('hooks', 3, flatten=True)
             *.hooks(3, flatten=True)
         """
-        s =  "*.%s(%s"%(self.name, ", ".join(map(repr, self.args)))
+        s = "*.%s(%s" % (self.name, ", ".join(map(repr, self.args)))
         if self.kwds:
-            if len(self.args) > 0:
+            if self.args:
                 s += ", "
-            s += ", ".join("%s=%s"%keyvalue for keyvalue in self.kwds.items())
+            s += ", ".join("%s=%s" % keyvalue for keyvalue in self.kwds.items())
         s += ")"
         return s
 
@@ -1709,7 +1634,7 @@ class AttrCallObject(object):
             sage: hash(x)       # random # indirect doctest
             210434060
             sage: type(hash(x))
-            <... 'int'>
+            <type 'int'>
             sage: y = attrcall('core', 3, blah = 1, flatten = True)
             sage: hash(y) == hash(x)
             True
@@ -1727,6 +1652,7 @@ class AttrCallObject(object):
         """
         return hash((self.args, tuple(self.kwds.items())))
 
+
 def attrcall(name, *args, **kwds):
     """
     Returns a callable which takes in an object, gets the method named
@@ -1750,6 +1676,7 @@ def attrcall(name, *args, **kwds):
     """
     return AttrCallObject(name, args, kwds)
 
+
 def call_method(obj, name, *args, **kwds):
     """
     Call the method ``name`` on ``obj``.
@@ -1766,6 +1693,7 @@ def call_method(obj, name, *args, **kwds):
     """
     return getattr(obj, name)(*args, **kwds)
 
+
 def is_in_string(line, pos):
     r"""
     Returns True if the character at position pos in line occurs
@@ -1915,7 +1843,8 @@ def inject_variable(name, value, warn=True):
     # also from functions in various modules.
     G = get_main_globals()
     if name in G and warn:
-        warnings.warn("redefining global value `%s`"%name, RuntimeWarning, stacklevel = 2)
+        warnings.warn("redefining global value `%s`" % name,
+                      RuntimeWarning, stacklevel=2)
     G[name] = value
 
 
